/**
 * COOS - Connected Objects Operating System (www.connectedobjects.org).
 *
 * Copyright (C) 2009 Telenor ASA and Tellu AS. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * You may also contact one of the following for additional information:
 * Telenor ASA, Snaroyveien 30, N-1331 Fornebu, Norway (www.telenor.no)
 * Tellu AS, Hagalokkveien 13, N-1383 Asker, Norway (www.tellu.no)
 */
package org.coos.plugin.logserver.impl;

import java.io.Serializable;


import org.coos.actorframe.ActorCS;
import org.coos.javaframe.State;
import org.coos.javaframe.StateMachine;
import org.coos.javaframe.messages.ActorMsg;
import org.coos.messaging.util.Log;
import org.coos.messaging.util.LogFactory;
import org.coos.plugin.logserver.api.LogMessageProperties;

public class LogServerCS extends ActorCS {

	private static final Log LOG = LogFactory.getLog(LogServerCS.class);
	
	protected State configured = new State("configured", this);
 

	public LogServerCS(String s) {
		super(s);
	}

	public void execTrans(ActorMsg sig, State st, StateMachine curfsm) {
		LogServerSM asm = (LogServerSM) curfsm;

		super.execTrans(sig, st, curfsm);

		if (st == idle) {
			if (sig.equals(START_PLAYING_MSG)) {
				performExit();
				try {
					String config = sig.getString(LogServerSM.CONFIG_FILE_KEY);
					if (config == null) {
						LOG.warn("Configuration parameter " + LogServerSM.CONFIG_FILE_KEY + " is null");
					} else {
						asm.configure(config);
					}
				} catch (Exception e) {
					LOG.error("Unexpected exception. Ignoring received logging event. " + e);
				}
				nextState(configured);
				return;
			}
		}
		
		if (st == configured) {
			if (sig.equals(LogMessageProperties.SEND_LOGGING_EVENT)) {
				try {
					byte[] serializedEvent = sig.getByteArray(LogMessageProperties.EVENT);
					asm.processLoggingEvent(serializedEvent);
				} catch (Exception e) {
					LOG.error("Unexpected exception. Ignoring received logging event. " + e);
				}
				sameState();
				return;
			}
		}
	}
}
